{% extends "common/buttons_list.html" %}{% load i18n %}

{% block before_menubar %}
<div class="col-xs-5">
  {% include "common/email_searchbar.html" with extraopts=extraopts %}
</div>
{% endblock %}

{% block menubar_classes %}col-xs-7{% endblock %}
